from random import choice
from string import lowercase, uppercase, digits

from paste.script.templates import Template
from paste.script.templates import var

CHARSET = lowercase+uppercase+digits


class FlaskTemplate(Template):
    vars = [
    ]
    use_cheetah = True
    required_templates = []

    def __init__(self, name):
        self.append_secret_key()
        super(FlaskTemplate, self).__init__(name)

    def check_vars(self, vars, command):
        if not command.options.no_interactive and not hasattr(command, '_deleted_once'):
            del vars['package']
            command._deleted_once = True
        return super(FlaskTemplate, self).check_vars(vars, command)

    def append_secret_key(self):
        default_key = ''.join(choice(CHARSET) for i in range(50))
        self.vars.append(var('secret_key', 'Secret key', default=default_key))


class FlaskBasicTemplate(FlaskTemplate):
    _template_dir = 'templates/flask_basic'
    summary = 'Flask basic project'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from setuptools import setup, find_packages

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read().strip()
DEPENDENCIES = [
    'distribute',
    'PasteScript>=1.3',
    'Cheetah',
    'fabric',
]


setup(
    name = 'flask-project-templates',
    version = '0.1',
    description = 'Paster templates for creating Flask projects',
    long_description = README,
    author = 'Mathieu D. (MatToufoutu)',
    author_email = 'mattoufootu@gmail.com',
    url = 'https://github.com/mattoufoutu/flask-project-templates',
    packages = find_packages('src'),
    package_dir = {'': 'src'},
    include_package_data = True,
    zip_safe = False,
    license = 'GPL',
    keywords = 'flask paster template',
    install_requires = DEPENDENCIES,
    classifiers = [
        'Development Status :: 1 - Planning',
        'Environment :: Plugins',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
        'Topic :: Software Development :: Code Generators',
    ],
    entry_points = """
    [paste.paster_create_template]
    flask_basic=flask_project_templates.flasktemplates:FlaskBasicTemplate
    """,
)
